==> staffology-0.1.1-py3-none-any.whl: staffology/api/pay_code/nominal_code_mappings_pay_code.py <==
from typing import Any, Dict, List, Optional

import httpx

from ...client import Client
from ...models.nominal_code_mapping import NominalCodeMapping
from ...types import Response


def _get_kwargs(
    employer_id: str,
    *,
    client: Client,
) -> Dict[str, Any]:
    url = "{}/employers/{employerId}/paycodes/nominalcodes".format(
        client.base_url, employerId=employer_id
    )

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    return {
        "method": "get",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
    }


def _parse_response(*, response: httpx.Response) -> Optional[List[NominalCodeMapping]]:
    if response.status_code == 200:
        response_200 = []
        _response_200 = response.json()
        for response_200_item_data in _response_200:
            response_200_item = NominalCodeMapping.from_dict(response_200_item_data)

            response_200.append(response_200_item)

        return response_200
    return None


def _build_response(*, response: httpx.Response) -> Response[List[NominalCodeMapping]]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    employer_id: str,
    *,
    client: Client,
) -> Response[List[NominalCodeMapping]]:
    """Get Nominal Code Mappings

     Returns the list of mappings of PayCodes to NominalCodes

    Args:
        employer_id (str):

    Returns:
        Response[List[NominalCodeMapping]]
    """

    kwargs = _get_kwargs(
        employer_id=employer_id,
        client=client,
    )

    response = httpx.request(
        verify=client.verify_ssl,
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    employer_id: str,
    *,
    client: Client,
) -> Optional[List[NominalCodeMapping]]:
    """Get Nominal Code Mappings

     Returns the list of mappings of PayCodes to NominalCodes

    Args:
        employer_id (str):

    Returns:
        Response[List[NominalCodeMapping]]
    """

    return sync_detailed(
        employer_id=employer_id,
        client=client,
    ).parsed


async def asyncio_detailed(
    employer_id: str,
    *,
    client: Client,
) -> Response[List[NominalCodeMapping]]:
    """Get Nominal Code Mappings

     Returns the list of mappings of PayCodes to NominalCodes

    Args:
        employer_id (str):

    Returns:
        Response[List[NominalCodeMapping]]
    """

    kwargs = _get_kwargs(
        employer_id=employer_id,
        client=client,
    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.request(**kwargs)

    return _build_response(response=response)


async def asyncio(
    employer_id: str,
    *,
    client: Client,
) -> Optional[List[NominalCodeMapping]]:
    """Get Nominal Code Mappings

     Returns the list of mappings of PayCodes to NominalCodes

    Args:
        employer_id (str):

    Returns:
        Response[List[NominalCodeMapping]]
    """

    return (
        await asyncio_detailed(
            employer_id=employer_id,
            client=client,
        )
    ).parsed

==> staffology-0.1.4-py3-none-any.whl: staffology/api/pay_code/nominal_code_mappings_pay_code.py <==
from typing import Any, Dict, List, Optional

import httpx
from staffology.propagate_exceptions import raise_staffology_exception

from ...client import Client
from ...models.nominal_code_mapping import NominalCodeMapping
from ...types import Response


def _get_kwargs(
    employer_id: str,
    *,
    client: Client,
) -> Dict[str, Any]:
    url = "{}/employers/{employerId}/paycodes/nominalcodes".format(
        client.base_url, employerId=employer_id
    )

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    return {
        "method": "get",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
    }


def _parse_response(*, response: httpx.Response) -> Optional[List[NominalCodeMapping]]:
    if response.status_code == 200:
        response_200 = []
        _response_200 = response.json()
        for response_200_item_data in _response_200:
            response_200_item = NominalCodeMapping.from_dict(response_200_item_data)

            response_200.append(response_200_item)

        return response_200
    return raise_staffology_exception(response)


def _build_response(*, response: httpx.Response) -> Response[List[NominalCodeMapping]]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    employer_id: str,
    *,
    client: Client,
) -> Response[List[NominalCodeMapping]]:
    """Get Nominal Code Mappings

     Returns the list of mappings of PayCodes to NominalCodes

    Args:
        employer_id (str):

    Returns:
        Response[List[NominalCodeMapping]]
    """

    kwargs = _get_kwargs(
        employer_id=employer_id,
        client=client,
    )

    response = httpx.request(
        verify=client.verify_ssl,
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    employer_id: str,
    *,
    client: Client,
) -> Optional[List[NominalCodeMapping]]:
    """Get Nominal Code Mappings

     Returns the list of mappings of PayCodes to NominalCodes

    Args:
        employer_id (str):

    Returns:
        Response[List[NominalCodeMapping]]
    """

    return sync_detailed(
        employer_id=employer_id,
        client=client,
    ).parsed


async def asyncio_detailed(
    employer_id: str,
    *,
    client: Client,
) -> Response[List[NominalCodeMapping]]:
    """Get Nominal Code Mappings

     Returns the list of mappings of PayCodes to NominalCodes

    Args:
        employer_id (str):

    Returns:
        Response[List[NominalCodeMapping]]
    """

    kwargs = _get_kwargs(
        employer_id=employer_id,
        client=client,
    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.request(**kwargs)

    return _build_response(response=response)


async def asyncio(
    employer_id: str,
    *,
    client: Client,
) -> Optional[List[NominalCodeMapping]]:
    """Get Nominal Code Mappings

     Returns the list of mappings of PayCodes to NominalCodes

    Args:
        employer_id (str):

    Returns:
        Response[List[NominalCodeMapping]]
    """

    return (
        await asyncio_detailed(
            employer_id=employer_id,
            client=client,
        )
    ).parsed
